##  Disable Partial Sync
The skipPartialSyncCondition property is no longer supported. To configure how partial sync should be executed, use the Partial Sync Mode property. For more information, see [Partial Sync Mode](https://help.sap.com/docs/leanix/ea/setup-in-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cbd707a4410148e4dabcbf8405203__partial_sync_mode).
